aboutsummaryrefslogtreecommitdiff
path: root/azalea-client/src/local_player.rs
diff options
context:
space:
mode:
authormat <github@matdoes.dev>2023-03-11 17:02:57 -0600
committermat <github@matdoes.dev>2023-03-11 17:02:57 -0600
commitcd0a1ed8d4c7670eb58d33f521026e760798e1a5 (patch)
tree5b47c3ab6ffa3cd2b87b26a24bfb854a53885fc4 /azalea-client/src/local_player.rs
parent40a0c8acfbfb88be791c295a14014468e2fd4298 (diff)
downloadazalea-drasl-cd0a1ed8d4c7670eb58d33f521026e760798e1a5.tar.xz
fix doc errors
Diffstat (limited to 'azalea-client/src/local_player.rs')
-rw-r--r--azalea-client/src/local_player.rs15
1 files changed, 8 insertions, 7 deletions
diff --git a/azalea-client/src/local_player.rs b/azalea-client/src/local_player.rs
index 7ec3d0dc..540ef3b4 100644
--- a/azalea-client/src/local_player.rs
+++ b/azalea-client/src/local_player.rs
@@ -5,7 +5,7 @@ use azalea_core::ChunkPos;
use azalea_protocol::packets::game::ServerboundGamePacket;
use azalea_world::{
entity::{self, Dead},
- Instance, PartialWorld,
+ Instance, PartialInstance,
};
use bevy_ecs::{
component::Component, entity::Entity, event::EventReader, query::Added, system::Query,
@@ -33,11 +33,12 @@ use crate::{
pub struct LocalPlayer {
packet_writer: mpsc::UnboundedSender<ServerboundGamePacket>,
- /// The partial world is the world this client currently has loaded. It has
- /// a limited render distance.
- pub partial_world: Arc<RwLock<PartialWorld>>,
- /// The world is the combined [`PartialWorld`]s of all clients in the same
- /// world. (Only relevant if you're using a shared world, i.e. a swarm)
+ /// The partial instance is the world this client currently has loaded. It
+ /// has a limited render distance.
+ pub partial_instance: Arc<RwLock<PartialInstance>>,
+ /// The world is the combined [`PartialInstance`]s of all clients in the
+ /// same world. (Only relevant if you're using a shared world, i.e. a
+ /// swarm)
pub world: Arc<RwLock<Instance>>,
/// A task that reads packets from the server. The client is disconnected
@@ -92,7 +93,7 @@ impl LocalPlayer {
packet_writer,
world,
- partial_world: Arc::new(RwLock::new(PartialWorld::new(
+ partial_instance: Arc::new(RwLock::new(PartialInstance::new(
client_information.view_distance.into(),
Some(entity),
))),